@@ -6,8 +6,11 @@ use crate::utils;
 use crate::LizError;
 
 pub fn inject_codes<'a>(lane: Context<'a>, liz: &Table<'a>) -> Result<(), LizError> {
-    let source =
-        lane.create_function(|lane, path: String| utils::treat_error(lane, liz_codes::source(&path)))?;
+    let code = lane
+        .create_function(|lane, path: String| utils::treat_error(lane, liz_codes::code(&path)))?;
+
+    let form = lane
+        .create_function(|_, part: String| Ok(liz_codes::form(&part)))?;
 
     let git_root_find = lane.create_function(|lane, path: String| {
         utils::treat_error(lane, liz_codes::git_root_find(&path))
@@ -21,7 +24,8 @@ pub fn inject_codes<'a>(lane: Context<'a>, liz: &Table<'a>) -> Result<(), LizErr
         utils::treat_error(lane, liz_codes::git_has_changes(&path))
     })?;
 
-    liz.set("source", source)?;
+    liz.set("code", code)?;
+    liz.set("form", form)?;
     liz.set("git_root_find", git_root_find)?;
     liz.set("git_is_ignored", git_is_ignored)?;
     liz.set("git_has_changes", git_has_changes)?;
